@@ -26,7 +26,6 @@ import logging
 
 from translate.storage import csvl10n, po
 
-
 logger = logging.getLogger(__name__)
 
 
@@ -103,7 +102,8 @@ class csv2po:
             if comment in self.commentindex:
                 del self.commentindex[comment]
 
-    def convertunit(self, csvunit):
+    @staticmethod
+    def convertunit(csvunit):
         """converts csv unit to po unit"""
         pounit = po.pounit(encoding="UTF-8")
         if csvunit.location:
