@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 #
 # Copyright 2007-2009 Zuza Software Foundation
 #
@@ -27,11 +26,10 @@ import logging
 
 from translate.storage import po, rc
 
-
 logger = logging.getLogger(__name__)
 
 
-class rc2po(object):
+class rc2po:
     """Convert a .rc file to a .po file for handling the translation."""
 
     def convert_store(self, input_store, duplicatestyle="msgctxt"):
@@ -49,14 +47,19 @@ class rc2po(object):
         output_store.removeduplicates(duplicatestyle)
         return output_store
 
-    def merge_store(self, template_store, input_store, blankmsgstr=False, duplicatestyle="msgctxt"):
+    def merge_store(
+        self, template_store, input_store, blankmsgstr=False, duplicatestyle="msgctxt"
+    ):
         """converts two .rc files to a .po file..."""
         output_store = po.pofile()
         output_header = output_store.init_headers(
             x_accelerator_marker="&",
             x_merge_on="location",
         )
-        output_header.addnote("extracted from %s, %s" % (template_store.filename, input_store.filename), "developer")
+        output_header.addnote(
+            f"extracted from {template_store.filename}, {input_store.filename}",
+            "developer",
+        )
         input_store.makeindex()
         for template_unit in template_store.units:
             origpo = self.convert_unit(template_unit, "developer")
@@ -73,12 +76,14 @@ class rc2po(object):
                     origpo.target = translatedpo.source
                 output_store.addunit(origpo)
             elif translatedpo is not None:
-                logging.error("error converting original rc definition %s",
-                              template_unit.name)
+                logging.error(
+                    "error converting original rc definition %s", template_unit.name
+                )
         output_store.removeduplicates(duplicatestyle)
         return output_store
 
-    def convert_unit(self, input_unit, commenttype):
+    @staticmethod
+    def convert_unit(input_unit, commenttype):
         """Converts a .rc unit to a .po unit. Returns None if empty or not for
         translation.
         """
@@ -92,15 +97,28 @@ class rc2po(object):
         return output_unit
 
 
-def convertrc(input_file, output_file, template_file, pot=False, duplicatestyle="msgctxt", charset=None, lang=None, sublang=None):
+def convertrc(
+    input_file,
+    output_file,
+    template_file,
+    pot=False,
+    duplicatestyle="msgctxt",
+    charset=None,
+    lang=None,
+    sublang=None,
+):
     """reads in input_file using rc, converts using rc2po, writes to output_file"""
     input_store = rc.rcfile(input_file, lang, sublang, encoding=charset)
     convertor = rc2po()
     if template_file is None:
-        output_store = convertor.convert_store(input_store, duplicatestyle=duplicatestyle)
+        output_store = convertor.convert_store(
+            input_store, duplicatestyle=duplicatestyle
+        )
     else:
         template_store = rc.rcfile(template_file, lang, sublang, encoding=charset)
-        output_store = convertor.merge_store(template_store, input_store, blankmsgstr=pot, duplicatestyle=duplicatestyle)
+        output_store = convertor.merge_store(
+            template_store, input_store, blankmsgstr=pot, duplicatestyle=duplicatestyle
+        )
     if output_store.isempty():
         return 0
     output_store.serialize(output_file)
@@ -109,21 +127,42 @@ def convertrc(input_file, output_file, template_file, pot=False, duplicatestyle=
 
 def main(argv=None):
     from translate.convert import convert
-    formats = {"rc": ("po", convertrc), ("rc", "rc"): ("po", convertrc),
-               "nls": ("po", convertrc), ("nls", "nls"): ("po", convertrc)}
-    parser = convert.ConvertOptionParser(formats, usetemplates=True, usepots=True, description=__doc__)
-    DEFAULTCHARSET = "cp1252"
+
+    formats = {
+        "rc": ("po", convertrc),
+        ("rc", "rc"): ("po", convertrc),
+        "nls": ("po", convertrc),
+        ("nls", "nls"): ("po", convertrc),
+    }
+    parser = convert.ConvertOptionParser(
+        formats, usetemplates=True, usepots=True, description=__doc__
+    )
     parser.add_option(
-        "", "--charset", dest="charset", default=DEFAULTCHARSET,
-        help="charset to use to decode the RC files (default: %s)" % DEFAULTCHARSET, metavar="CHARSET")
-    DEFAULTLANG = "LANG_ENGLISH"
+        "",
+        "--charset",
+        dest="charset",
+        default="auto",
+        help="charset to use to decode the RC files (autodetection is used by default)",
+        metavar="CHARSET",
+    )
+    DEFAULTLANG = None
     parser.add_option(
-        "-l", "--lang", dest="lang", default=DEFAULTLANG,
-        help="LANG entry (default: %s)" % DEFAULTLANG, metavar="LANG")
-    DEFAULTSUBLANG = "SUBLANG_DEFAULT"
+        "-l",
+        "--lang",
+        dest="lang",
+        default=DEFAULTLANG,
+        help="LANG entry (default: %s)" % DEFAULTLANG,
+        metavar="LANG",
+    )
+    DEFAULTSUBLANG = None
     parser.add_option(
-        "", "--sublang", dest="sublang", default=DEFAULTSUBLANG,
-        help="SUBLANG entry (default: %s)" % DEFAULTSUBLANG, metavar="SUBLANG")
+        "",
+        "--sublang",
+        dest="sublang",
+        default=DEFAULTSUBLANG,
+        help="SUBLANG entry (default: %s)" % DEFAULTSUBLANG,
+        metavar="SUBLANG",
+    )
     parser.add_duplicates_option()
     parser.passthrough.append("pot")
     parser.passthrough.append("charset")
@@ -132,5 +171,5 @@ def main(argv=None):
     parser.run(argv)
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     main()
