@@ -27,7 +27,6 @@ import re
 from itertools import starmap
 from wsgiref.util import shift_path_info
 
-
 try:
     from resolver import resolve
 except ImportError:
@@ -162,7 +161,7 @@ class Selector:
                 k = k[5:]
             named[k] = v
         environ["selector.vars"] = dict(named)
-        for k in named.keys():
+        for k in named:
             if k.isdigit():
                 unnamed.append((k, named.pop(k)))
         unnamed.sort()
@@ -357,14 +356,16 @@ class SimpleParser:
             self._pos += 1
         return f"(?P<{name}>{pattern})"
 
-    def lastly(self, regex):
+    @staticmethod
+    def lastly(regex):
         """Process the result of __call__ right before it returns.
 
         Adds the ^ and the $ to the beginning and the end, respectively.
         """
         return "^%s$" % regex
 
-    def openended(self, regex):
+    @staticmethod
+    def openended(regex):
         """Process the result of ``__call__`` right before it returns.
 
         Adds the ^ to the beginning but no $ to the end.
