@@ -181,14 +181,14 @@ def rc_statement():
     block_start = (Keyword("{") | Keyword("BEGIN")).set_name("block_start")
     block_end = (Keyword("}") | Keyword("END")).set_name("block_end")
 
-    name_id = Group(Word(alphas, alphanums + "_")).set_name("name_id")
-
     numbers = Word(nums)
 
     integerconstant = numbers ^ Combine("0x" + numbers)
 
+    name_id = Group(Word(alphas, alphanums + "_") | integerconstant)
+
     constant = Combine(
-        Optional(Keyword("NOT")) + (name_id | integerconstant),
+        Optional(Keyword("NOT")) + Group(name_id),
         adjacent=False,
         join_string=" ",
     )
@@ -206,6 +206,7 @@ def rc_statement():
     undefined_control = (
         Group(
             name_id.set_results_name("id_control")
+            + Optional(",")
             + delimited_list(
                 concatenated_string ^ constant ^ numbers ^ Group(combined_constants)
             ).set_results_name("values_")
@@ -237,6 +238,12 @@ def rc_statement():
     popup_block <<= Group(
         Keyword("POPUP")("block_type")
         + Optional(quoted_string("caption"))
+        + Optional(
+            ","
+            + delimited_list(
+                concatenated_string ^ constant ^ numbers ^ Group(combined_constants)
+            ).set_results_name("values_")
+        )
         + block_start
         + ZeroOrMore(Group(menu_item | popup_block | comments), stop_on=block_end)(
             "elements"
@@ -246,7 +253,7 @@ def rc_statement():
 
     menu = (
         name_id("block_id")
-        + Keyword("MENU")("block_type")
+        + (Keyword("MENU") | Keyword("MENUEX"))("block_type")
         + block_options
         + block_start
         + ZeroOrMore(popup_block | comments, stop_on=block_end)
@@ -258,7 +265,7 @@ def rc_statement():
 
 def generate_stringtable_name(identifier):
     """Return the name generated for a stringtable element."""
-    return "STRINGTABLE." + identifier
+    return f"STRINGTABLE.{identifier}"
 
 
 def generate_menu_pre_name(block_type, block_id):
@@ -280,7 +287,7 @@ def generate_popup_pre_name(pre_name, caption):
 
 def generate_popup_caption_name(pre_name):
     """Return the name generated for a caption of a popup."""
-    return "%s.POPUP.CAPTION" % (pre_name)
+    return f"{pre_name}.POPUP.CAPTION"
 
 
 def generate_menuitem_name(pre_name, block_type, identifier):
@@ -290,7 +297,7 @@ def generate_menuitem_name(pre_name, block_type, identifier):
 
 def generate_dialog_caption_name(block_type, identifier):
     """Return the name generated for a caption of a dialog."""
-    return "{}.{}.{}".format(block_type, identifier, "CAPTION")
+    return f"{block_type}.{identifier}.CAPTION"
 
 
 def generate_dialog_control_name(block_type, block_id, control_type, identifier):
@@ -340,9 +347,7 @@ class rcfile(base.TranslationStore):
             self.addunit(newunit)
 
         for element in popup.elements:
-
             if element.block_type and element.block_type == "MENUITEM":
-
                 if element.values_ and len(element.values_) >= 2:
                     newtext = extract_text(element.values_)
                     if newtext:
@@ -382,14 +387,17 @@ class rcfile(base.TranslationStore):
 
         for statement in results:
             # Parse pragma
-            if statement[0] == "#pragma" and "code_page" in statement[1]:
+            if (
+                statement[0] == "#pragma"
+                and "code_page" in statement[1]
+                and self.encoding not in ("utf-8", "utf-16")
+            ):
                 expected_encoding = parse_encoding_pragma(statement[1])
                 if expected_encoding and expected_encoding != self.encoding:
                     self.units = []
                     self.parse(rcsrc, expected_encoding)
                     return
             if statement.language:
-
                 if self.lang is None or statement.language == self.lang:
                     if self.sublang is None or statement.sublanguage == self.sublang:
                         self.lang = statement.language
@@ -402,9 +410,7 @@ class rcfile(base.TranslationStore):
                 continue
 
             if processblocks and statement.block_type:
-
                 if statement.block_type in ("DIALOG", "DIALOGEX"):
-
                     if statement.caption:
                         newunit = rcunit(escape_to_python(statement.caption[1:-1]))
                         newunit.name = generate_dialog_caption_name(
@@ -434,7 +440,6 @@ class rcfile(base.TranslationStore):
                             control.values_[0].startswith('"')
                             or control.values_[0].startswith("'")
                         ):
-
                             # The first value without quoted chars.
                             newtext = extract_text(control.values_)
                             if newtext:
@@ -450,20 +455,17 @@ class rcfile(base.TranslationStore):
 
                     continue
 
-                if statement.block_type in ("MENU"):
-
+                if statement.block_type in ("MENU", "MENUEX"):
                     pre_name = generate_menu_pre_name(
                         statement.block_type, statement.block_id[0]
                     )
 
                     for popup in statement.popups:
-
                         self.add_popup_units(pre_name, popup)
 
                     continue
 
                 if statement.block_type in ("STRINGTABLE"):
-
                     for text in statement.controls:
                         if isinstance(text, str):
                             # This is a comment
