@@ -39,7 +39,6 @@ from translate.storage import lisa
 from translate.storage.placeables import general
 from translate.storage.workflow import StateEnum as state
 
-
 # TODO: handle translation types
 
 
@@ -312,7 +311,7 @@ class tsunit(lisa.LISAunit):
             self.markfuzzy(False)
 
     def isobsolete(self):
-        return self._gettype() == "obsolete" or self._gettype() == "vanished"
+        return self._gettype() in ("obsolete", "vanished")
 
     def get_state_n(self):
         type = self._gettype()
@@ -354,7 +353,7 @@ class tsfile(lisa.LISAfile):
 """
     XMLindent = {"indent": "    ", "skip": ["TS"], "toplevel": False}
     # For conformance with Qt output, write XML declaration with double quotes
-    XMLdoublequotes = True
+    XMLuppercaseEncoding = False
     namespace = ""
 
     def __init__(self, *args, **kwargs):
@@ -445,9 +444,10 @@ class tsfile(lisa.LISAfile):
         if contextname is None:
             contextname = unit.getcontextname()
 
-        if self._contextname != contextname:
-            if not self._switchcontext(contextname, comment, createifmissing):
-                return None
+        if self._contextname != contextname and not self._switchcontext(
+            contextname, comment, createifmissing
+        ):
+            return None
         super().addunit(unit, new)
         #        lisa.setXMLspace(unit.xmlelement, "preserve")
         return unit
