@@ -45,7 +45,6 @@ class YAMLUnit(base.DictUnit):
     """A YAML entry"""
 
     IdClass = YAMLUnitId
-    DefaultDict = dict
 
     def __init__(self, source=None, **kwargs):
         # Ensure we have ID (for serialization)
@@ -64,10 +63,6 @@ class YAMLUnit(base.DictUnit):
     def source(self, source):
         self.target = source
 
-    def setid(self, value):
-        self._id = value
-        self._unitid = None
-
     def getid(self):
         return self._id
 
@@ -149,7 +144,8 @@ class YAMLFile(base.DictStore):
                     "Previous: %s" % (type(data), data, prev)
                 )
 
-    def preprocess(self, data):
+    @staticmethod
+    def preprocess(data):
         """Preprocess hook for child formats"""
         return data
 
@@ -168,7 +164,7 @@ class YAMLFile(base.DictStore):
         try:
             self._original = self.yaml.load(input)
         except YAMLError as e:
-            message = e.problem if hasattr(e, "problem") else e.message
+            message = getattr(e, "problem", getattr(e, "message", str(e)))
             if hasattr(e, "problem_mark"):
                 message += f" {e.problem_mark}"
             raise base.ParseError(message)
@@ -213,6 +209,8 @@ class RubyYAMLFile(YAMLFile):
         if isinstance(data, CommentedMap) and len(data) == 1:
             lang = list(data.keys())[0]
             self.settargetlanguage(lang)
+            if data[lang] is None:
+                data[lang] = CommentedMap()
             return data[lang]
         return data
 
