@@ -1,24 +1,31 @@
-
 from io import BytesIO
 
 from pytest import mark
 
-from translate.storage import po, statsdb
+from translate.storage import po
 from translate.tools import pocount
 
+from ._test_utils import requires_py38_mark, test_po_files
+
 
 class TestCount:
-
-    def count(self, source, expectedsource, target=None, expectedtarget=None):
+    @staticmethod
+    def count(source, expectedsource, target=None, expectedtarget=None):
         """simple helper to check the respective word counts"""
         poelement = po.pounit(source)
         if target is not None:
             poelement.target = target
-        wordssource, wordstarget = statsdb.wordsinunit(poelement)
-        print('Source (expected=%d; actual=%d): "%s"' % (expectedsource, wordssource, source))
+        wordssource, wordstarget = pocount.wordsinunit(poelement)
+        print(
+            'Source (expected=%d; actual=%d): "%s"'
+            % (expectedsource, wordssource, source)
+        )
         assert wordssource == expectedsource
         if target is not None:
-            print('Target (expected=%d; actual=%d): "%s"' % (expectedtarget, wordstarget, target))
+            print(
+                'Target (expected=%d; actual=%d): "%s"'
+                % (expectedtarget, wordstarget, target)
+            )
             assert wordstarget == expectedtarget
 
     def test_simple_count_zero(self):
@@ -90,11 +97,10 @@ class TestCount:
 
 class TestPOCount:
     """
-    This only tests the old (memory-based) pocount method, not the current
-    code based on statsdb.
+    This only tests the old (memory-based) pocount method.
     """
 
-    inputdata = br'''
+    inputdata = rb"""
 msgid "translated unit"
 msgstr "translated unit"
 
@@ -117,44 +123,61 @@ msgstr ""
 # untranslated
 #~ msgid "obsolete untranslated unit"
 #~ msgstr ""
-'''
+"""
 
     def test_translated(self):
         pofile = BytesIO(self.inputdata)
-        stats = pocount.calcstats_old(pofile)
-        assert stats['translated'] == 1
+        stats = pocount.calcstats(pofile)
+        assert stats["translated"] == 1
 
     def test_fuzzy(self):
         pofile = BytesIO(self.inputdata)
-        stats = pocount.calcstats_old(pofile)
-        assert stats['fuzzy'] == 1
+        stats = pocount.calcstats(pofile)
+        assert stats["fuzzy"] == 1
 
     def test_untranslated(self):
         pofile = BytesIO(self.inputdata)
-        stats = pocount.calcstats_old(pofile)
-        assert stats['untranslated'] == 1
+        stats = pocount.calcstats(pofile)
+        assert stats["untranslated"] == 1
 
     def test_total(self):
         pofile = BytesIO(self.inputdata)
-        stats = pocount.calcstats_old(pofile)
-        assert stats['total'] == 3
+        stats = pocount.calcstats(pofile)
+        assert stats["total"] == 3
 
     def test_translatedsourcewords(self):
         pofile = BytesIO(self.inputdata)
-        stats = pocount.calcstats_old(pofile)
-        assert stats['translatedsourcewords'] == 2
+        stats = pocount.calcstats(pofile)
+        assert stats["translatedsourcewords"] == 2
 
     def test_fuzzysourcewords(self):
         pofile = BytesIO(self.inputdata)
-        stats = pocount.calcstats_old(pofile)
-        assert stats['fuzzysourcewords'] == 2
+        stats = pocount.calcstats(pofile)
+        assert stats["fuzzysourcewords"] == 2
 
     def test_untranslatedsourcewords(self):
         pofile = BytesIO(self.inputdata)
-        stats = pocount.calcstats_old(pofile)
-        assert stats['untranslatedsourcewords'] == 2
+        stats = pocount.calcstats(pofile)
+        assert stats["untranslatedsourcewords"] == 2
 
     def test_totalsourcewords(self):
         pofile = BytesIO(self.inputdata)
-        stats = pocount.calcstats_old(pofile)
-        assert stats['totalsourcewords'] == 6
+        stats = pocount.calcstats(pofile)
+        assert stats["totalsourcewords"] == 6
+
+
+@requires_py38_mark
+@mark.parametrize("style", ["csv", "full", "short-strings", "short-words"])
+@mark.parametrize("incomplete", [True, False], ids=lambda v: f"incomplete={v}")
+@mark.parametrize("no_color", [True, False], ids=lambda v: f"no-color={v}")
+def test_output(style, incomplete, no_color, capsys, snapshot):
+    opts = [f"--{style}"]
+    if incomplete:
+        opts.append("--incomplete")
+    if no_color:
+        opts.append("--no-color")
+
+    pocount.main([*opts, *test_po_files])
+    stdout = capsys.readouterr()[0]
+
+    assert stdout == snapshot
